==> haskell-pcre-heavy-1.0.0.4-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pcre-heavy
version:              1.0.0.4
visibility:           public
id:                   pcre-heavy-1.0.0.4-3RtGpDtvRRYEm9cTdWHDQi
key:                  pcre-heavy-1.0.0.4-3RtGpDtvRRYEm9cTdWHDQi
license:              LicenseRef-PublicDomain
copyright:            2015-2025 Val Packett <val@packett.cool>
maintainer:           val@packett.cool
author:               Val Packett
homepage:             https://codeberg.org/valpackett/pcre-heavy
synopsis:
    A regexp (regex) library on top of pcre-light you can actually use.

description:
    A PCRE-based regular expressions library with support for multiple matches and replacements.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/string-conversions convertible strings> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.

category:             Web
abi:                  7bef6a598ddb730c34811bd15d521ce0
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcre-heavy
hs-libraries:         HSpcre-heavy-1.0.0.4-3RtGpDtvRRYEm9cTdWHDQi
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W
    string-conversions-0.4.0.1-BGbREFbeQrc4pc6EE5c0sM
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-heavy-1.0.0.4-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pcre-heavy
version:              1.0.0.4
visibility:           public
id:                   pcre-heavy-1.0.0.4-I7NFnBfdbhA1w5uLEaB2SE
key:                  pcre-heavy-1.0.0.4-I7NFnBfdbhA1w5uLEaB2SE
license:              LicenseRef-PublicDomain
copyright:            2015-2025 Val Packett <val@packett.cool>
maintainer:           val@packett.cool
author:               Val Packett
homepage:             https://codeberg.org/valpackett/pcre-heavy
synopsis:
    A regexp (regex) library on top of pcre-light you can actually use.

description:
    A PCRE-based regular expressions library with support for multiple matches and replacements.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/string-conversions convertible strings> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.

category:             Web
abi:                  e6096ed4c48cc0e504ebb1767b539037
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcre-heavy
hs-libraries:         HSpcre-heavy-1.0.0.4-I7NFnBfdbhA1w5uLEaB2SE
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W
    string-conversions-0.4.0.1-Cvuioi3eoLTCuVWgq4Uxic
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
